@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: 6e78b0a430e44fedbd287caa428076566f65045a $
+ * $Id: e5ae611d970cd766f7f23fe5a70c6483e66aceb5 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -26,7 +26,7 @@ require_once 'phing/listener/AnsiColorLogger.php';
  *
  * @author    Patrick McAndrew <patrick@urg.name>
  * @copyright 2013. All rights reserved
- * @version   $Id: 6e78b0a430e44fedbd287caa428076566f65045a $
+ * @version   $Id: e5ae611d970cd766f7f23fe5a70c6483e66aceb5 $
  * @package   phing.listener
  */
 class TargetLogger extends AnsiColorLogger
@@ -51,7 +51,7 @@ class TargetLogger extends AnsiColorLogger
      */
     public function targetFinished(BuildEvent $event)
     {
-        $msg .= PHP_EOL . "Target time: " . self::formatTime(
+        $msg = PHP_EOL . "Target time: " . self::formatTime(
                 Phing::currentTimeMillis() - $this->targetStartTime
             ) . PHP_EOL;
         $event->setMessage($msg, Project::MSG_INFO);
