@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: d60cc0674b74f234c03334f5c60905c44de64476 $
+ *  $Id: 0e41dd4805552f11260977c86fbbc05fa5b57f54 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -54,9 +54,15 @@ class FileInputStream extends InputStream
             throw new Exception("Invalid argument type for \$file.");
         }
 
+        if (!$this->file->exists()) {
+            throw new IOException("Unable to open " . $this->file->__toString() . " for reading. File does not exists.");
+        }
+        if (!$this->file->canRead()) {
+            throw new IOException("Unable to open " . $this->file->__toString() . " for reading. File not readable.");
+        }
         $stream = @fopen($this->file->getAbsolutePath(), "rb");
         if ($stream === false) {
-            throw new IOException("Unable to open " . $this->file->__toString() . " for reading: " . $php_errormsg);
+            throw new IOException("Unable to open " . $this->file->__toString() . " for reading: " . print_r(error_get_last(), true));
         }
 
         parent::__construct($stream);
