@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: 3c4fbf1439d15b8491fc853e50e60035eb1f2605 $
+ * $Id: 4b9d4bc0ada3044961fd261245d566a72b3789a9 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -29,7 +29,7 @@ require_once 'phing/Task.php';
  *
  * @package phing.tasks.ext
  * @author  Alexey Borzov <avb@php.net>
- * @version $Id: 3c4fbf1439d15b8491fc853e50e60035eb1f2605 $
+ * @version $Id: 4b9d4bc0ada3044961fd261245d566a72b3789a9 $
  */
 abstract class HttpTask extends Task
 {
@@ -183,7 +183,11 @@ abstract class HttpTask extends Task
             throw new BuildException("Required attribute 'url' is missing");
         }
 
-        $this->processResponse($this->createRequest()->send());
+        try {
+            $this->processResponse($this->createRequest()->send());
+        } catch (HTTP_Request2_MessageException $e) {
+            throw new BuildException($e);
+        }
     }
 
     /**
