@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 89cfb9d4709a4e67b4f77d4da5b6c6249624230f $
+ *  $Id: 2d0f1f7fa10c416782647339da7fc5d26780d911 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -86,7 +86,7 @@ require_once 'phing/tasks/ext/PearPackageTask.php';
  * @author   Stuart Binge <stuart.binge@complinet.com>
  * @author   Hans Lellelid <hans@xmpl.org>
  * @package  phing.tasks.ext
- * @version  $Id: 89cfb9d4709a4e67b4f77d4da5b6c6249624230f $
+ * @version  $Id: 2d0f1f7fa10c416782647339da7fc5d26780d911 $
  */
 class PearPackage2Task extends PearPackageTask
 {
@@ -285,7 +285,7 @@ class PearPackage2Task extends PearPackageTask
         $this->pkg->addRelease();
         $this->pkg->generateContents();
         $e = $this->pkg->writePackageFile();
-        if (PEAR::isError($e)) {
+        if (@PEAR::isError($e)) {
             throw new BuildException("Unable to write package file.", new Exception($e->getMessage()));
         }
     }
