@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: e635b2512b71e17b616bda5e66b412984c0718b0 $
+ *  $Id: 1cb309b7992d03271825878803e5cabb757b9d63 $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -25,7 +25,7 @@ require_once 'phing/Task.php';
  * A PHP code sniffer task. Checking the style of one or more PHP source files.
  *
  * @author  Dirk Thomas <dirk.thomas@4wdmedia.de>
- * @version $Id: e635b2512b71e17b616bda5e66b412984c0718b0 $
+ * @version $Id: 1cb309b7992d03271825878803e5cabb757b9d63 $
  * @package phing.tasks.ext
  */
 class PhpCodeSnifferTask extends Task
@@ -63,6 +63,10 @@ class PhpCodeSnifferTask extends Task
     // parameters to customize output
     protected $showSniffs = false;
     protected $format = 'full';
+
+    /**
+     * @var PhpCodeSnifferTask_FormatterElement[]
+     */
     protected $formatters = array();
 
     /**
@@ -322,7 +326,7 @@ class PhpCodeSnifferTask extends Task
 
     /**
      * Create object for nested formatter element.
-     * @return CodeSniffer_FormatterElement
+     * @return PhpCodeSnifferTask_FormatterElement
      */
     public function createFormatter()
     {
@@ -530,8 +534,12 @@ class PhpCodeSnifferTask extends Task
         $_SERVER['argv'] = array('t');
         $_SERVER['argc'] = 1;
         foreach ($this->formatters as $fe) {
-            $output = ($fe->getUseFile() ? $fe->getOutFile() : null);
-            $_SERVER['argv'][] = '--report-' . $fe->getType() . '=' . $output;
+            if ($fe->getUseFile()) {
+                $_SERVER['argv'][] = '--report-' . $fe->getType() . '=' . $fe->getOutfile();
+            } else {
+                $_SERVER['argv'][] = '--report-' . $fe->getType();
+            }
+
             $_SERVER['argc']++;
         }
 
@@ -567,7 +575,7 @@ class PhpCodeSnifferTask extends Task
             $outputFile = $this->docFile->getPath();
             $check = file_put_contents($outputFile, $output);
 
-            if (is_bool($check) && !$check) {
+            if ($check === false) {
                 throw new BuildException('Error writing doc to ' . $outputFile);
             }
         } elseif ($this->docGenerator !== '' && $this->docFile === null) {
