@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 51ec1dd117e7c11d416654a444491cab3028073d $
+ *  $Id: dc5d657411378951be19ff5d321a9442afc1a70c $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -33,7 +33,7 @@ include_once 'phing/parser/CustomChildCreator.php';
  * @author  Hans Lellelid <hans@xmpl.org>
  * @author    Andreas Aderhold <andi@binarycloud.com>
  * @copyright 2001,2002 THYRELL. All rights reserved
- * @version   $Id: 51ec1dd117e7c11d416654a444491cab3028073d $
+ * @version   $Id: dc5d657411378951be19ff5d321a9442afc1a70c $
  * @package   phing.tasks.system.condition
  */
 abstract class ConditionBase extends ProjectComponent
@@ -42,6 +42,35 @@ abstract class ConditionBase extends ProjectComponent
 
     public $conditions = array(); // needs to be public for "inner" class access
 
+    /** @var string $taskName */
+    private $taskName = 'condition';
+
+    public function __construct($taskName = 'component')
+    {
+        $this->taskName = $taskName;
+    }
+
+    /**
+     * Sets the name to use in logging messages.
+     *
+     * @param string $name The name to use in logging messages.
+     *                     Should not be <code>null</code>.
+     */
+    public function setTaskName($name)
+    {
+        $this->taskName = $name;
+    }
+
+    /**
+     * Returns the name to use in logging messages.
+     *
+     * @return string the name to use in logging messages.
+     */
+    public function getTaskName()
+    {
+        return $this->taskName;
+    }
+
     /**
      * @return int
      */
@@ -274,6 +303,22 @@ abstract class ConditionBase extends ProjectComponent
         return $this->conditions[$num - 1];
     }
 
+    public function createIsFileSelected()
+    {
+        include_once 'phing/tasks/system/condition/IsFileSelected.php';
+        $num = array_push($this->conditions, new IsFileSelected());
+
+        return $this->conditions[$num - 1];
+    }
+
+    public function createMatches()
+    {
+        include_once 'phing/tasks/system/condition/Matches.php';
+        $num = array_push($this->conditions, new Matches());
+
+        return $this->conditions[$num - 1];
+    }
+
     /**
      * @param  string         $elementName
      * @param  Project        $project
