@@ -1,6 +1,6 @@
 <?php
 /*
- *  $Id: 125cf5dba67f81869e08a950d61bf3f321190c33 $
+ *  $Id: a49cf8d88ef1fb89fbef5d26107432cf17bd072b $
  *
  * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -320,6 +320,15 @@ class Path extends DataType
                     $d = new PhingFile($dir, $dstr);
                     $result[] = $d->getAbsolutePath();
                 }
+            } elseif ($o instanceof FileSet) {
+                $fs = $o;
+                $ds = $fs->getDirectoryScanner($this->getProject());
+                $filestrs = $ds->getIncludedFiles();
+                $dir = $fs->getDir($this->getProject());
+                foreach ($filestrs as $fstr) {
+                    $d = new PhingFile($dir, $fstr);
+                    $result[] = $d->getAbsolutePath();
+                }
             } elseif ($o instanceof FileList) {
                 $fl = $o;
                 $dirstrs = $fl->getFiles($this->project);
